"""List of all available help pages."""

from __future__ import annotations

HELP_PAGES = {
    "_index": "Index",
    "budgets": "Budgets",
    "conversion": "Conversion",
    "import": "Import",
    "options": "Options",
    "beancount_syntax": "Beancount Syntax",
    "features": "Fava's features",
    "filters": "Filtering entries",
    "extensions": "Extensions",
}
